@@ -128,7 +128,7 @@ def connect_with_cert(cert, path_to_cert, url, args, wait_thread, clVarsCore,
     client = None
 
     bio = M2Crypto.BIO.openfile(CERT_KEY)
-    rsa = M2Crypto.m2.rsa_read_key(bio._ptr(), lambda *unused: None)
+    rsa = M2Crypto.m2.rsa_read_key(bio._ptr(), lambda *unused: "")
     store_passwd = None
     if not rsa:
         port = args.port or clVarsCore.Get('core.cl_core_port')
